@@ -187,14 +187,14 @@ class Mixture:
         logger.info('X-ray energy (wavelength): %d eV (%.5f A)'\
                     %(energy, 12398.4/energy))
         logger.info('Sample thickness: %.5f cm' %(self.thick))
-        logger.info(f"""{'atom':<8s} {'wt frac':<8s} {"f'":<8s} {"f''":<8s} {'total xs':<15s} {'rayleigh xs':<15s} {'compton xs':<15s} {'photoelectric xs':<15s}""")
+        logger.info(f"""{'atom':<10s} {'wt frac':<10s} {"f'":<10s} {"f''":<10s} {'total xs':<12s} {'rayleigh xs':<12s} {'compton xs':<12s} {'photoel xs':<12s}""")
         for w in self.stoi.keys():
             u = Atom(w)
             barnxs, cmxs = u.atom_mu(energy)
             sig_ua = cmxs['tot']
             mix_sigma += sig_ua*self.weig[u.name]
             f1, f2 = u.atom_ff(energy)
-            logger.info('%-8s %-8.3f %-8.3f %-8.3f %-15.3f %-15.3f %-15.3f %-15.3f' \
+            logger.info('%-10s %-10.3f %-10.3f %-10.3f %-12.3f %-12.3f %-12.3f %-12.3f' \
                  %(u.name, self.weig[u.name], f1, f2,
                    barnxs['tot']*self.stoi[u.name],
                    barnxs['ra']*self.stoi[u.name],
@@ -240,9 +240,11 @@ class Mixture:
             f1 += f1_w; f2 += f2_w
         self.mu = np.multiply(mix_total, self.prop['d'])
         self.transm = np.exp(-self.mu*self.thick)
-        logger.info(f"""{'energy':<8s} {'% transm':<8s} {'mu:<8s'} {'muR':<8s} {"f'":<8s} {"f''":<8s} {'total xs':<15s} {'rayleigh xs':<15s} {'compton xs':<15s} {'photoelectric xs':<15s}""")
+        logger.info(f"""{' ':<10s}|{' ':<10s}|{' ':<10s}|{' ':<10s}|{' ':<10s}|{' ':<10s}|{'   ':<12s}|{'   ':<12s}|{'   ':<12s}|{'   ':<12s}""")
+        logger.info(f"""{'energy':>10s}|{'% transm':>10s}|{'mu':>10s}|{'muR':>10s}|{"f'":>10s}|{"f''":>10s}|{'total xs':>12s}|{'rayleigh xs':>12s}|{'compton xs':>12s}|{'photoelectric xs':>12s}""")
+        logger.info(f"""{' ':<10s}|{' ':<10s}|{' ':<10s}|{' ':<10s}|{' ':<10s}|{' ':<10s}|{'   ':<12s}|{'   ':<12s}|{'   ':<12s}|{'   ':<12s}""")
         for i in range(len(energy)):
-            logger.info('%8d|%10.3f|%8.3f|%8.3f|%8.3f|%8.3f' \
+            logger.info('%10d|%10.3f|%10.3f|%10.3f|%10.3f|%10.3f|%12.3f|%12.3f|%12.3f|%12.3f' \
                         %(energy[i], 100*self.transm[i], self.mu[i], self.mu[i]*0.5*self.thick, f1[i], f2[i],
                           mix_total[i], mix_rayl[i], mix_comp[i], mix_phoe[i]) )            
         return self.transm, f1, f2
@@ -295,4 +297,4 @@ def console():
      ##--close logger
     logging.shutdown()
     
-thelogger = Logg(__name__)
\ No newline at end of file
+thelogger = Logg(__name__)
